@@ -1,6 +1,4 @@
 package Courriel;
-# git description: v0.35-6-g0fcadef
-$Courriel::VERSION = '0.36';
 
 use 5.10.0;
 
@@ -8,19 +6,20 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.40';
+
 use Courriel::Headers;
 use Courriel::Helpers qw( unique_boundary );
 use Courriel::Part::Multipart;
 use Courriel::Part::Single;
-use Courriel::Types
-    qw( ArrayRef Bool Headers Maybe Part Str StringRef );
+use Courriel::Types qw( ArrayRef Bool Headers Maybe Part Str StringRef );
 use DateTime;
 use DateTime::Format::Mail;
 use DateTime::Format::Natural;
 use Email::Address;
 use Encode qw( encode );
 use List::AllUtils qw( uniq );
-use MooseX::Params::Validate qw( validated_list );
+use MooseX::Params::Validate 0.21 qw( validated_list );
 
 use Moose;
 use MooseX::StrictConstructor;
@@ -39,7 +38,7 @@ has top_level_part => (
             is_multipart
             stream_to
             )
-    ]
+    ],
 );
 
 has subject => (
@@ -129,31 +128,31 @@ has html_body_part => (
 sub part_count {
     my $self = shift;
 
-    return $self->is_multipart()
-        ? $self->top_level_part()->part_count()
+    return $self->is_multipart
+        ? $self->top_level_part->part_count
         : 1;
 }
 
 sub parts {
     my $self = shift;
 
-    return $self->is_multipart()
-        ? $self->top_level_part()->parts()
-        : $self->top_level_part();
+    return $self->is_multipart
+        ? $self->top_level_part->parts
+        : $self->top_level_part;
 }
 
 sub clone_without_attachments {
     my $self = shift;
 
-    my $plain_body = $self->plain_body_part();
-    my $html_body  = $self->html_body_part();
+    my $plain_body = $self->plain_body_part;
+    my $html_body  = $self->html_body_part;
 
-    my $headers = $self->headers();
+    my $headers = $self->headers;
 
     if ( $plain_body && $html_body ) {
         my $ct = Courriel::Header::ContentType->new(
-            mime_type  => 'multipart/alternative',
-            attributes => { boundary => unique_boundary() },
+            mime_type => 'multipart/alternative',
+            attributes => { boundary => unique_boundary },
         );
 
         return Courriel->new(
@@ -167,33 +166,33 @@ sub clone_without_attachments {
     elsif ($plain_body) {
         return Courriel->new(
             part => Courriel::Part::Single->new(
-                content_type    => $plain_body->content_type(),
+                content_type    => $plain_body->content_type,
                 headers         => $headers,
-                encoding        => $plain_body->encoding(),
-                encoded_content => $plain_body->encoded_content(),
+                encoding        => $plain_body->encoding,
+                encoded_content => $plain_body->encoded_content,
             )
         );
     }
     elsif ($html_body) {
         return Courriel->new(
             part => Courriel::Part::Single->new(
-                content_type    => $html_body->content_type(),
+                content_type    => $html_body->content_type,
                 headers         => $headers,
-                encoding        => $html_body->encoding(),
-                encoded_content => $html_body->encoded_content(),
+                encoding        => $html_body->encoding,
+                encoded_content => $html_body->encoded_content,
             )
         );
     }
 
-    die "Cannot find a text or html body in this email!";
+    die 'Cannot find a text or html body in this email!';
 }
 
 sub _build_subject {
     my $self = shift;
 
-    my $subject = $self->headers()->get('Subject');
+    my $subject = $self->headers->get('Subject');
 
-    return $subject ? $subject->value() : undef;
+    return $subject ? $subject->value : undef;
 }
 
 {
@@ -204,13 +203,13 @@ sub _build_subject {
         my $self = shift;
 
         my @possible = (
-            ( map { $_->value() } $self->headers()->get('Date') ),
+            ( map { $_->value } $self->headers->get('Date') ),
             (
                 reverse
-                    map { $self->_find_date_received( $_->value() ) }
-                    $self->headers()->get('Received')
+                    map { $self->_find_date_received( $_->value ) }
+                    $self->headers->get('Received')
             ),
-            ( map { $_->value() } $self->headers()->get('Resent-Date') ),
+            ( map { $_->value } $self->headers->get('Resent-Date') ),
         );
 
         # Stolen from Email::Date and then modified
@@ -221,7 +220,7 @@ sub _build_subject {
 
             unless ($dt) {
                 $dt = $natural_parser->parse_datetime($possible);
-                next unless $natural_parser->success();
+                next unless $natural_parser->success;
             }
 
             $dt->set_time_zone('UTC');
@@ -247,8 +246,8 @@ sub _find_date_received {
 sub _build_to {
     my $self = shift;
 
-    my @addresses = map { Email::Address->parse( $_->value() ) }
-        $self->headers()->get('To');
+    my @addresses = map { Email::Address->parse( $_->value ) }
+        $self->headers->get('To');
 
     return $self->_unique_addresses( \@addresses );
 }
@@ -256,8 +255,8 @@ sub _build_to {
 sub _build_cc {
     my $self = shift;
 
-    my @addresses = map { Email::Address->parse( $_->value() ) }
-        $self->headers()->get('CC');
+    my @addresses = map { Email::Address->parse( $_->value ) }
+        $self->headers->get('CC');
 
     return $self->_unique_addresses( \@addresses );
 }
@@ -265,8 +264,8 @@ sub _build_cc {
 sub _build_from {
     my $self = shift;
 
-    my @addresses = Email::Address->parse( map { $_->value() }
-            $self->headers()->get('From') );
+    my @addresses = Email::Address->parse( map { $_->value }
+            $self->headers->get('From') );
 
     return $addresses[0];
 }
@@ -274,7 +273,7 @@ sub _build_from {
 sub _build_recipients {
     my $self = shift;
 
-    my @addresses = ( $self->to(), $self->cc() );
+    my @addresses = ( $self->to, $self->cc );
 
     return $self->_unique_addresses( \@addresses );
 }
@@ -282,8 +281,7 @@ sub _build_recipients {
 sub _build_participants {
     my $self = shift;
 
-    my @addresses
-        = grep {defined} ( $self->from(), $self->to(), $self->cc() );
+    my @addresses = grep {defined} ( $self->from, $self->to, $self->cc );
 
     return $self->_unique_addresses( \@addresses );
 }
@@ -293,7 +291,7 @@ sub _unique_addresses {
     my $addresses = shift;
 
     my %seen;
-    return [ grep { !$seen{ $_->original() }++ } @{$addresses} ];
+    return [ grep { !$seen{ $_->original }++ } @{$addresses} ];
 }
 
 sub _build_plain_body_part {
@@ -301,8 +299,8 @@ sub _build_plain_body_part {
 
     return $self->first_part_matching(
         sub {
-            $_[0]->mime_type() eq 'text/plain'
-                && $_[0]->is_inline();
+            $_[0]->mime_type eq 'text/plain'
+                && $_[0]->is_inline;
         }
     );
 }
@@ -312,8 +310,8 @@ sub _build_html_body_part {
 
     return $self->first_part_matching(
         sub {
-            $_[0]->mime_type() eq 'text/html'
-                && $_[0]->is_inline();
+            $_[0]->mime_type eq 'text/html'
+                && $_[0]->is_inline;
         }
     );
 }
@@ -322,12 +320,13 @@ sub first_part_matching {
     my $self  = shift;
     my $match = shift;
 
-    my @parts = $self->top_level_part();
+    my @parts = $self->top_level_part;
 
+    ## no critic (ControlStructures::ProhibitCStyleForLoops)
     for ( my $part = shift @parts; $part; $part = shift @parts ) {
         return $part if $match->($part);
 
-        push @parts, $part->parts() if $part->is_multipart();
+        push @parts, $part->parts if $part->is_multipart;
     }
 }
 
@@ -335,13 +334,14 @@ sub all_parts_matching {
     my $self  = shift;
     my $match = shift;
 
-    my @parts = $self->top_level_part();
+    my @parts = $self->top_level_part;
 
     my @match;
+    ## no critic (ControlStructures::ProhibitCStyleForLoops)
     for ( my $part = shift @parts; $part; $part = shift @parts ) {
         push @match, $part if $match->($part);
 
-        push @parts, $part->parts() if $part->is_multipart();
+        push @parts, $part->parts if $part->is_multipart;
     }
 
     return @match;
@@ -362,7 +362,7 @@ sub all_parts_matching {
         );
 
         my $part = Courriel::Part::Single->new(
-            headers         => $self->headers(),
+            headers         => $self->headers,
             encoded_content => $text,
         );
 
@@ -394,12 +394,12 @@ sub all_parts_matching {
 }
 
 sub _parse {
-    my $class     = shift;
-    my $text      = shift;
+    my $class = shift;
+    my $text  = shift;
 
     my ( $sep_idx, $headers ) = $class->_parse_headers($text);
 
-    substr( ${$text}, 0, $sep_idx ) = q{};
+    substr( ${$text}, 0, $sep_idx, q{} );
 
     return $class->_parse_parts( $text, $headers );
 }
@@ -415,15 +415,16 @@ sub _parse_headers {
     # but we may find broken lines. The key is that it starts with From
     # followed by space, not a colon.
     ${$text} =~ s/^From\s+.+$Courriel::Helpers::LINE_SEP_RE//;
+
     # Some broken emails may split the From line in an arbitrary spot
     ${$text} =~ s/^[^:]+$Courriel::Helpers::LINE_SEP_RE//g;
 
     if ( ${$text} =~ /^(.+?)($Courriel::Helpers::LINE_SEP_RE)\g{2}/s ) {
         $header_text = $1 . $2;
-        $sep_idx     = ( length $header_text ) + ( length $2 );
+        $sep_idx = ( length $header_text ) + ( length $2 );
     }
     else {
-        return ( 0, Courriel::Headers::->new() );
+        return ( 0, Courriel::Headers::->new );
     }
 
     my $headers = Courriel::Headers::->parse(
@@ -451,7 +452,7 @@ sub _parse_headers {
 
         my $ct = $ct[0] // $fake_ct;
 
-        if ( $ct->mime_type() !~ /^multipart/i ) {
+        if ( $ct->mime_type !~ /^multipart/i ) {
             return Courriel::Part::Single->new(
                 headers         => $headers,
                 encoded_content => $text,
@@ -471,7 +472,7 @@ sub _parse_multipart {
     my $boundary = $ct->attribute_value('boundary');
 
     die q{The message's mime type claims this is a multipart message (}
-        . $ct->mime_type()
+        . $ct->mime_type
         . q{) but it does not specify a boundary.}
         unless defined $boundary && length $boundary;
 
@@ -507,11 +508,11 @@ sub _parse_multipart {
                 && $epilogue =~ /\S/ ? ( epilogue => $epilogue ) : ()
         ),
         boundary => $boundary,
-        parts    => [ map { $class->_parse( \$_ ) } @part_text ],
+        parts => [ map { $class->_parse( \$_ ) } @part_text ],
     );
 }
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -527,20 +528,20 @@ Courriel - High level email parsing and manipulation
 
 =head1 VERSION
 
-version 0.36
+version 0.40
 
 =head1 SYNOPSIS
 
     my $email = Courriel->parse( text => $raw_email );
 
-    print $email->subject();
+    print $email->subject;
 
-    print $_->address() for $email->participants();
+    print $_->address for $email->participants;
 
-    print $email->datetime()->year();
+    print $email->datetime->year;
 
-    if ( my $part = $email->plain_body_part() ) {
-        print $part->content();
+    if ( my $part = $email->plain_body_part ) {
+        print $part->content;
     }
 
 =head1 DESCRIPTION
@@ -698,7 +699,7 @@ strings, or via multiple calls to the output.
 For large emails, streaming can be much more memory efficient than generating
 a single string in memory.
 
-=head2 $part->as_string()
+=head2 $email->as_string()
 
 Returns the email as a string, along with its headers. Lines will be
 terminated with "\r\n".
@@ -792,7 +793,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Gregory Oschwald Zbigniew Łukasiak
+=for stopwords Gregory Oschwald Ricardo Signes Zbigniew Łukasiak
 
 =over 4
 
@@ -802,13 +803,17 @@ Gregory Oschwald <goschwald@maxmind.com>
 
 =item *
 
+Ricardo Signes <rjbs@users.noreply.github.com>
+
+=item *
+
 Zbigniew Łukasiak <zzbbyy@gmail.com>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
