@@ -1,11 +1,10 @@
 package Courriel::Builder;
-{
-  $Courriel::Builder::VERSION = '0.31';
-}
 
 use strict;
 use warnings;
 
+our $VERSION = '0.40';
+
 use Carp qw( croak );
 use Courriel;
 use Courriel::Header::ContentType;
@@ -20,7 +19,7 @@ use DateTime::Format::Mail;
 use Devel::PartialDump;
 use File::Basename qw( basename );
 use File::LibMagic;
-use File::Slurp qw( read_file );
+use File::Slurp::Tiny qw( read_file );
 use List::AllUtils qw( first );
 use MooseX::Params::Validate qw( pos_validated_list validated_list );
 use Scalar::Util qw( blessed reftype );
@@ -45,7 +44,7 @@ BEGIN {
 
 use Sub::Exporter -setup => {
     exports => \@exports,
-    groups  => { default => \@exports },
+    groups => { default => \@exports },
 };
 
 {
@@ -65,6 +64,7 @@ use Sub::Exporter -setup => {
         my @attachments;
 
         for my $p (@_) {
+            ## no critic (ControlStructures::ProhibitCascadingIfElse)
             if ( $p->{header} ) {
                 push @headers, @{ $p->{header} };
             }
@@ -89,7 +89,7 @@ use Sub::Exporter -setup => {
             );
 
             $body_part = Courriel::Part::Multipart->new(
-                headers      => Courriel::Headers->new(),
+                headers      => Courriel::Headers->new,
                 content_type => $ct,
                 parts        => [ $plain_body, $html_body ],
             );
@@ -97,7 +97,7 @@ use Sub::Exporter -setup => {
         else {
             $body_part = first {defined} $plain_body, $html_body;
 
-            croak "Cannot call build_email without a plain or html body"
+            croak 'Cannot call build_email without a plain or html body'
                 unless $body_part;
         }
 
@@ -106,7 +106,7 @@ use Sub::Exporter -setup => {
                 mime_type => 'multipart/mixed' );
 
             $body_part = Courriel::Part::Multipart->new(
-                headers      => Courriel::Headers->new(),
+                headers      => Courriel::Headers->new,
                 content_type => $ct,
                 parts        => [
                     $body_part,
@@ -128,8 +128,8 @@ use Sub::Exporter -setup => {
 }
 
 sub _bad_value {
-    croak "A weird value was passed to build_email: "
-        . Devel::PartialDump->new()->dump( $_[0] );
+    croak 'A weird value was passed to build_email: '
+        . Devel::PartialDump->new->dump( $_[0] );
 }
 
 sub _add_required_headers {
@@ -139,14 +139,13 @@ sub _add_required_headers {
 
     unless ( $keys{date} ) {
         push @{$headers},
-            (
-            Date => DateTime::Format::Mail->format_datetime( DateTime->now() )
-            );
+            ( Date =>
+                DateTime::Format::Mail->format_datetime( DateTime->now ) );
     }
 
     unless ( $keys{'message-id'} ) {
         push @{$headers},
-            ( 'Message-Id' => Email::MessageID->new()->in_brackets() );
+            ( 'Message-Id' => Email::MessageID->new->in_brackets );
     }
 
     unless ( $keys{'mime-version'} ) {
@@ -179,7 +178,7 @@ sub _add_required_headers {
         );
 
         if ( blessed $from ) {
-            $from = $from->format();
+            $from = $from->format;
         }
 
         return { header => [ From => $from ] };
@@ -197,7 +196,7 @@ sub _add_required_headers {
             MX_PARAMS_VALIDATE_NO_CACHE => 1,
         );
 
-        @to = map { blessed($_) ? $_->format() : $_ } @to;
+        @to = map { blessed($_) ? $_->format : $_ } @to;
 
         return { header => [ To => join ', ', @to ] };
     }
@@ -214,7 +213,7 @@ sub _add_required_headers {
             MX_PARAMS_VALIDATE_NO_CACHE => 1,
         );
 
-        @cc = map { blessed($_) ? $_->format() : $_ } @cc;
+        @cc = map { blessed($_) ? $_->format : $_ } @cc;
 
         return { header => [ Cc => join ', ', @cc ] };
     }
@@ -274,7 +273,7 @@ sub html_body {
 
     if (@attachments) {
         $body = Courriel::Part::Multipart->new(
-            headers      => Courriel::Headers->new(),
+            headers      => Courriel::Headers->new,
             content_type => Courriel::Header::ContentType->new(
                 mime_type => 'multipart/related'
             ),
@@ -291,7 +290,7 @@ sub html_body {
 {
     my @spec = (
         mime_type => { isa => NonEmptyStr },
-        charset   => {
+        charset => {
             isa     => NonEmptyStr,
             default => 'UTF-8',
         },
@@ -312,12 +311,12 @@ sub html_body {
         );
 
         my $ct = Courriel::Header::ContentType->new(
-            mime_type  => $mime_type,
+            mime_type => $mime_type,
             attributes => { charset => $charset },
         );
 
         my $body = Courriel::Part::Single->new(
-            headers      => Courriel::Headers->new(),
+            headers      => Courriel::Headers->new,
             content_type => $ct,
             encoding     => $encoding,
             content      => $content,
@@ -334,10 +333,11 @@ sub attach {
         : @_;
 
     return {
-        attachment => $p{file} ? _part_for_file(%p) : _part_for_content(%p) };
+        attachment => $p{file} ? _part_for_file(%p) : _part_for_content(%p)
+    };
 }
 
-my $flm = File::LibMagic->new();
+my $flm = File::LibMagic->new;
 
 {
     my @spec = (
@@ -405,12 +405,14 @@ my $flm = File::LibMagic->new();
 sub _content_type {
     my $type = shift;
 
-    return Courriel::Header::ContentType->new( mime_type => 'application/unknown' )
+    return Courriel::Header::ContentType->new(
+        mime_type => 'application/unknown' )
         unless defined $type;
 
     my ( $mime_type, $attr ) = parse_header_with_attributes($type);
 
-    return Courriel::Header::ContentType->new( mime_type => 'application/unknown' )
+    return Courriel::Header::ContentType->new(
+        mime_type => 'application/unknown' )
         unless defined $mime_type && length $mime_type;
 
     return Courriel::Header::ContentType->new(
@@ -457,7 +459,7 @@ Courriel::Builder - Build emails with sugar
 
 =head1 VERSION
 
-version 0.31
+version 0.40
 
 =head1 SYNOPSIS
 
@@ -475,7 +477,7 @@ version 0.31
             attach('path/to/other-image.jpg'),
         ),
         attach('path/to/spreadsheet.xls'),
-        attach($file_content),
+        attach( content => $file_content ),
     );
 
 =head1 DESCRIPTION
@@ -484,6 +486,8 @@ This module provides some sugar syntax for emails of all shapes sizes, from
 simple emails with a plain text body to emails with both plain and html
 bodies, html with attached images, etc.
 
+=encoding utf-8
+
 =head1 API
 
 This module exports all of the following functions by default. It uses
@@ -713,13 +717,9 @@ This creates an email with this structure:
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
