@@ -1,9 +1,11 @@
 package Courriel::Header::Disposition;
-$Courriel::Header::Disposition::VERSION = '0.36';
+
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.40';
+
 use Courriel::Types qw( Bool Maybe NonEmptyStr );
 use DateTime;
 use DateTime::Format::Mail;
@@ -14,7 +16,8 @@ use MooseX::StrictConstructor;
 
 extends 'Courriel::Header';
 
-with 'Courriel::Role::HeaderWithAttributes' => { main_value_key => 'disposition' };
+with 'Courriel::Role::HeaderWithAttributes' =>
+    { main_value_key => 'disposition' };
 
 has '+value' => (
     required => 0,
@@ -53,7 +56,7 @@ has filename => (
         exists $_[0]->_attributes()->{filename}
             ? $_[0]->_attributes()->{filename}->value()
             : undef;
-    }
+    },
 );
 
 {
@@ -110,7 +113,7 @@ Courriel::Header::Disposition - The content disposition for an email part
 
 =head1 VERSION
 
-version 0.36
+version 0.40
 
 =head1 SYNOPSIS
 
@@ -258,7 +261,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
