@@ -1,9 +1,11 @@
 package Courriel::HeaderAttribute;
-$Courriel::HeaderAttribute::VERSION = '0.36';
+
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.40';
+
 use Courriel::HeaderAttribute;
 use Courriel::Helpers qw( quote_and_escape_attribute_value );
 use Courriel::Types qw( Maybe NonEmptyStr Str );
@@ -50,12 +52,14 @@ override BUILDARGS => sub {
     return $p;
 };
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _stream_to {
     my $self   = shift;
     my $output = shift;
 
-    $output->( $self->_as_string() );
+    $output->( $self->_as_string );
 }
+## use critic
 
 {
     my $non_attribute_char = qr{
@@ -71,13 +75,13 @@ sub _stream_to {
     sub _as_string {
         my $self = shift;
 
-        my $value = $self->value();
+        my $value = $self->value;
 
         my $transport_method = '_simple_parameter';
 
         if (   $value =~ /[\x00-\x1f]|\x7f|[^\p{ASCII}]/
-            || defined $self->language()
-            || $self->charset() ne 'us-ascii' ) {
+            || defined $self->language
+            || $self->charset ne 'us-ascii' ) {
 
             $value = encode( 'utf-8', $value );
             $value
@@ -116,12 +120,13 @@ sub _stream_to {
     }
 }
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _simple_parameter {
     my $self  = shift;
     my $order = shift;
     my $value = shift;
 
-    my $param = $self->name();
+    my $param = $self->name;
     $param .= q{*} . $order if defined $order;
     $param .= q{=};
     $param .= $value;
@@ -134,7 +139,7 @@ sub _quoted_parameter {
     my $order = shift;
     my $value = shift;
 
-    my $param = $self->name();
+    my $param = $self->name;
     $param .= q{*} . $order if defined $order;
     $param .= q{=};
 
@@ -150,23 +155,23 @@ sub _encoded_parameter {
     my $order = shift;
     my $value = shift;
 
-    my $param = $self->name();
+    my $param = $self->name;
     $param .= q{*} . $order if defined $order;
     $param .= q{*=};
 
     # XXX (1) - does it makes sense to just say everything is utf-8? in theory
     # someone could pass through binary data in another encoding.
     unless ($order) {
-        $param .= 'UTF-8' . q{'}
-            . ( $self->language() // q{} ) . q{'};
+        $param .= 'UTF-8' . q{'} . ( $self->language // q{} ) . q{'};
     }
 
     $param .= $value;
 
     return $param;
 }
+## use critic;
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -182,12 +187,12 @@ Courriel::HeaderAttribute - A single attribute belonging to a header
 
 =head1 VERSION
 
-version 0.36
+version 0.40
 
 =head1 SYNOPSIS
 
   my $ct = $headers->get('Content-Type');
-  print $ct->get_attribute('charset')->value();
+  print $ct->get_attribute('charset')->value;
 
 =head1 DESCRIPTION
 
@@ -268,7 +273,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
