@@ -1,9 +1,11 @@
 package Courriel::Headers;
-$Courriel::Headers::VERSION = '0.36';
+
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.40';
+
 use Courriel::Header;
 use Courriel::Header::ContentType;
 use Courriel::Header::Disposition;
@@ -69,7 +71,8 @@ override BUILDARGS => sub {
     if ( reftype( $p->{headers} ) eq 'ARRAY' ) {
         my $headers = $p->{headers};
 
-        for ( my $i = 1 ; $i < @{$headers} ; $i += 2 ) {
+        ## no critic (ControlStructures::ProhibitCStyleForLoops)
+        for ( my $i = 1; $i < @{$headers}; $i += 2 ) {
             next if blessed( $headers->[ $i - 1 ] );
 
             my $name = $headers->[ $i - 1 ];
@@ -112,9 +115,10 @@ sub _inflate_header {
 sub _build_key_indices {
     my $self = shift;
 
-    my $headers = $self->_headers();
+    my $headers = $self->_headers;
 
     my %indices;
+    ## no critic (ControlStructures::ProhibitCStyleForLoops)
     for ( my $i = 0; $i < @{$headers}; $i += 2 ) {
         push @{ $indices{ lc $headers->[$i] } }, $i + 1;
     }
@@ -132,7 +136,7 @@ sub _build_key_indices {
             @spec,
         );
 
-        return @{ $self->_headers() }[ $self->_key_indices_for($name) ];
+        return @{ $self->_headers }[ $self->_key_indices_for($name) ];
     }
 }
 
@@ -147,8 +151,8 @@ sub _build_key_indices {
         );
 
         return
-            map { $_->value() }
-            @{ $self->_headers() }[ $self->_key_indices_for($name) ];
+            map { $_->value }
+            @{ $self->_headers }[ $self->_key_indices_for($name) ];
     }
 }
 
@@ -172,7 +176,7 @@ sub _key_indices_for {
             @spec,
         );
 
-        my $headers = $self->_headers();
+        my $headers = $self->_headers;
 
         my $last_index = ( $self->_key_indices_for($name) )[-1];
 
@@ -189,7 +193,7 @@ sub _key_indices_for {
             push @{$headers}, ( $name => $header );
         }
 
-        $self->_clear_key_indices();
+        $self->_clear_key_indices;
 
         return;
     }
@@ -202,6 +206,8 @@ sub _key_indices_for {
     );
 
     # Used to add things like Resent or Received headers
+
+    ## no critic (Subroutines::ProhibitBuiltinHomonyms)
     sub unshift {
         my $self = shift;
         my ( $name, $value ) = pos_validated_list(
@@ -211,7 +217,7 @@ sub _key_indices_for {
             MX_PARAMS_VALIDATE_NO_CACHE => 1,
         );
 
-        my $headers = $self->_headers();
+        my $headers = $self->_headers;
 
         my $header
             = blessed($value)
@@ -237,13 +243,13 @@ sub _key_indices_for {
             @spec,
         );
 
-        my $headers = $self->_headers();
+        my $headers = $self->_headers;
 
         for my $idx ( reverse $self->_key_indices_for($name) ) {
             splice @{$headers}, $idx - 1, 2;
         }
 
-        $self->_clear_key_indices();
+        $self->_clear_key_indices;
 
         return;
     }
@@ -271,8 +277,8 @@ sub _key_indices_for {
 
 {
     my $horiz_text = qr/[^\x0a\x0d]/;
-    my $horiz_ws = qr/[ \t]/;
-    my $line_re  = qr/
+    my $horiz_ws   = qr/[ \t]/;
+    my $line_re    = qr/
                       (?:
                           ([^\s:][^:\n\r]*)  # a header name
                           :                  # followed by a colon
@@ -289,7 +295,7 @@ sub _key_indices_for {
 
     sub parse {
         my $class = shift;
-        my ( $text ) = validated_list(
+        my ($text) = validated_list(
             \@_,
             @spec,
         );
@@ -298,7 +304,8 @@ sub _key_indices_for {
 
         $class->_maybe_fix_broken_headers($text);
 
-        while ( ${$text} =~ /\G${line_re}$Courriel::Helpers::LINE_SEP_RE/gc ) {
+        while ( ${$text} =~ /\G${line_re}$Courriel::Helpers::LINE_SEP_RE/gc )
+        {
             if ( defined $1 ) {
                 push @headers, $1, $2;
             }
@@ -315,23 +322,26 @@ sub _key_indices_for {
                 #   structured header field are semantically interpreted as a single
                 #   space character.
                 $headers[-1] .= q{ } if length $headers[-1];
-                $headers[-1] .= $3 if defined $3;
+                $headers[-1] .= $3   if defined $3;
             }
         }
 
         my $pos = pos ${$text} // 0;
         if ( $pos != length ${$text} ) {
-            my @lines = split $Courriel::Helpers::LINE_SEP_RE, substr( ${$text}, 0, $pos );
+            my @lines = split $Courriel::Helpers::LINE_SEP_RE,
+                substr( ${$text}, 0, $pos );
             my $count = ( scalar @lines ) + 1;
 
-            my $line = ( split $Courriel::Helpers::LINE_SEP_RE, ${$text} )[ $count - 1 ];
+            my $line = ( split $Courriel::Helpers::LINE_SEP_RE, ${$text} )
+                [ $count - 1 ];
 
             die defined $line
                 ? "Found an unparseable chunk in the header text starting at line $count:\n  $line"
                 : 'Could not parse headers at all';
         }
 
-        for ( my $i = 1 ; $i < @headers ; $i += 2 ) {
+        ## no critic (ControlStructures::ProhibitCStyleForLoops)
+        for ( my $i = 1; $i < @headers; $i += 2 ) {
             $headers[$i] = $class->_mime_decode( $headers[$i] );
         }
 
@@ -346,7 +356,8 @@ sub _maybe_fix_broken_headers {
     # Some broken email messages have a newline in the headers that isn't
     # acting as a continuation, it's just an arbitrary line break. See
     # t/data/stress-test/mbox_mime_applemail_1xb.txt
-    ${$text} =~ s/$Courriel::Helpers::LINE_SEP_RE([^\s:][^:]+$Courriel::Helpers::LINE_SEP_RE)/$1/g;
+    ${$text}
+        =~ s/$Courriel::Helpers::LINE_SEP_RE([^\s:][^:]+$Courriel::Helpers::LINE_SEP_RE)/$1/g;
 
     return;
 }
@@ -367,8 +378,8 @@ sub _maybe_fix_broken_headers {
 
         my %skip = map { lc $_ => 1 } @{$skip};
 
-        for my $header ( grep { blessed($_) } @{$self->_headers()} ) {
-            next if $skip{ lc $header->name() };
+        for my $header ( grep { blessed($_) } @{ $self->_headers } ) {
+            next if $skip{ lc $header->name };
 
             $header->stream_to( charset => $charset, output => $output );
         }
@@ -424,14 +435,14 @@ sub as_string {
                     ),
                     ws      => $+{ws},
                     is_mime => 1,
-                    };
+                };
             }
             else {
                 push @chunks, {
                     content => $+{unencoded},
                     ws      => $+{ws},
                     is_mime => 0,
-                    };
+                };
             }
         }
 
@@ -441,8 +452,8 @@ sub as_string {
             $result .= $chunks[$i]{content};
             $result .= ( $chunks[$i]{ws} // q{} )
                 unless $chunks[$i]{is_mime}
-                    && $chunks[ $i + 1 ]
-                    && $chunks[ $i + 1 ]{is_mime};
+                && $chunks[ $i + 1 ]
+                && $chunks[ $i + 1 ]{is_mime};
         }
 
         return $result;
@@ -464,7 +475,7 @@ sub _decode_one_word {
     }
 }
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -480,7 +491,7 @@ Courriel::Headers - The headers for an email part
 
 =head1 VERSION
 
-version 0.36
+version 0.40
 
 =head1 SYNOPSIS
 
@@ -619,7 +630,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
