@@ -1,9 +1,11 @@
 package Courriel::Part::Multipart;
-$Courriel::Part::Multipart::VERSION = '0.35';
+
 use strict;
 use warnings;
 use namespace::autoclean;
 
+our $VERSION = '0.40';
+
 use Courriel::HeaderAttribute;
 use Courriel::Helpers qw( unique_boundary );
 use Courriel::Types qw( ArrayRef NonEmptyStr Part );
@@ -39,19 +41,21 @@ has _parts => (
 
 sub BUILD {
     my $self = shift;
-    my $p = shift;
+    my $p    = shift;
 
-    my $boundary = delete $p->{boundary} // unique_boundary();
-    my $existing = $self->content_type()->attribute('boundary');
+    my $boundary = delete $p->{boundary} // unique_boundary;
+    my $existing = $self->content_type->attribute('boundary');
 
-    $self->content_type()->_set_attribute(
+    ## no critic (Subroutines::ProtectPrivateSubs)
+    $self->content_type->_set_attribute(
         boundary => Courriel::HeaderAttribute->new(
-            name => ( $existing ? $existing->name() : 'boundary' ),
+            name => ( $existing ? $existing->name : 'boundary' ),
             value => $boundary,
         )
     );
+    ## use critic
 
-    $_->_set_container($self) for $self->parts();
+    $_->_set_container($self) for $self->parts;
 
     return;
 }
@@ -60,22 +64,19 @@ sub is_attachment {0}
 sub is_inline     {0}
 sub is_multipart  {1}
 
-sub _default_mime_type {
-    return 'multipart/mixed';
-}
-
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _stream_content {
     my $self   = shift;
     my $output = shift;
 
-    $output->( $self->preamble(), $Courriel::Helpers::CRLF )
-        if $self->has_preamble();
+    $output->( $self->preamble, $Courriel::Helpers::CRLF )
+        if $self->has_preamble;
 
-    for my $part ( $self->parts() ) {
+    for my $part ( $self->parts ) {
         $output->(
             $Courriel::Helpers::CRLF,
             '--',
-            $self->boundary(),
+            $self->boundary,
             $Courriel::Helpers::CRLF,
         );
 
@@ -85,24 +86,25 @@ sub _stream_content {
     $output->(
         $Courriel::Helpers::CRLF,
         '--',
-        $self->boundary(),
+        $self->boundary,
         '--',
         $Courriel::Helpers::CRLF
     );
 
-    $output->( $self->epilogue(), $Courriel::Helpers::CRLF )
-        if $self->has_epilogue();
+    $output->( $self->epilogue, $Courriel::Helpers::CRLF )
+        if $self->has_epilogue;
 
     return;
 }
+## use critic
 
 sub boundary {
     my $self = shift;
 
-    return $self->content_type()->attribute_value('boundary');
+    return $self->content_type->attribute_value('boundary');
 }
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -118,12 +120,12 @@ Courriel::Part::Multipart - A part which contains other parts
 
 =head1 VERSION
 
-version 0.35
+version 0.40
 
 =head1 SYNOPSIS
 
-  my $headers = $part->headers();
-  my $ct = $part->content_type();
+  my $headers = $part->headers;
+  my $ct = $part->content_type;
 
   for my $subpart ( $part->parts ) { ... }
 
@@ -226,8 +228,6 @@ output can be a subroutine reference, a filehandle, or an object with a
 C<print()> method. The output may be sent as a single string, as a list of
 strings, or via multiple calls to the output.
 
-See the C<as_string()> method for documentation on the C<charset> parameter.
-
 =head2 $part->as_string()
 
 Returns the part as a string, along with its headers. Lines will be terminated
@@ -235,20 +235,16 @@ with "\r\n".
 
 =head1 ROLES
 
-This class does the C<Courriel::Role::Part> and L<Courriel::Role::Streams>
+This class does the C<Courriel::Role::Part> and C<Courriel::Role::Streams>
 roles.
 
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 CONTRIBUTOR
-
-Zbigniew Łukasiak <zzbbyy@gmail.com>
-
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
