@@ -1,8 +1,10 @@
 package Email::Abstract::Courriel;
-$Email::Abstract::Courriel::VERSION = '0.36';
+
 use strict;
 use warnings;
 
+our $VERSION = '0.40';
+
 use Courriel;
 
 use parent 'Email::Abstract::Plugin';
@@ -16,19 +18,19 @@ sub construct {
 
 sub get_header {
     my ( $class, $obj, $header ) = @_;
-    my @values = map { $_->value() } $obj->headers()->get($header);
+    my @values = map { $_->value } $obj->headers->get($header);
     return wantarray ? @values : $values[0];
 }
 
 sub get_body {
     my ( $class, $obj ) = @_;
-    return $obj->top_level_part()->content();
+    return $obj->as_string;
 }
 
 sub set_header {
     my ( $class, $obj, $header, @data ) = @_;
-    $obj->headers()->remove($header);
-    $obj->headers()->add( $header => $_ ) for @data;
+    $obj->headers->remove($header);
+    $obj->headers->add( $header => $_ ) for @data;
 }
 
 sub set_body {
@@ -38,7 +40,7 @@ sub set_body {
 
 sub as_string {
     my ( $class, $obj ) = @_;
-    $obj->as_string();
+    $obj->as_string;
 }
 
 1;
@@ -55,7 +57,7 @@ Email::Abstract::Courriel - Email::Abstract wrapper for Courriel
 
 =head1 VERSION
 
-version 0.36
+version 0.40
 
 =head1 DESCRIPTION
 
@@ -74,7 +76,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
